/*
# BUILD sources []
# BUILD api_version_check 0
# BUILD include_dirs []
*/
#include "../config.h"

#include "GL.EXT.vertex_array.0110.inc"
